{% extends 'django_spire/item/item.html' %}

{% block item_title %}
	Item
{% endblock %}

{% block item_row_content %}
	<div class="col">
        {% include 'django_spire/element/attribute_element.html' with attribute_title='Title' attribute_value='Value' %}
    </div>
	<div class="col">
        {% include 'django_spire/element/attribute_element.html' with attribute_title='Title' attribute_value='Value' %}
    </div>
	<div class="col">
        {% include 'django_spire/element/attribute_element.html' with attribute_title='Title' attribute_value='Value' %}
    </div>
    <div class="col-2 text-center">
        {% include 'django_spire/element/attribute_element.html' with attribute_title='Dropdown' %}
        {% include 'django_spire/dropdown/ellipsis_dropdown.html' with view_url='#' edit_url='#' delete_url='#' %}
    </div>
    <div class="col-1 text-center">
        {% include 'django_spire/element/attribute_element.html' with attribute_title='Modal' %}
        {% include 'django_spire/dropdown/ellipsis_modal_dropdown.html' with view_url='#' edit_url='#' delete_url='#' %}
    </div>
{% endblock %}
