{% extends 'django_spire/page/full_page.html' %}

{% load static %}

{% block css_include %}
    {{ form.media.css }}
{% endblock %}

{% block js_include_top %}
    {{ form.media.js }}
{% endblock %}

{% block full_page_content %}
    {% include 'django_spire/card/form_card.html' %}
{% endblock %}
