# These imports are for the migrations to work as a single app "django_spire_knowledge"

from django_spire.knowledge.entry import models
from django_spire.knowledge.entry.version import models
from django_spire.knowledge.entry.version.block import models
from django_spire.knowledge.collection import models
