{% if status == 'published' %}
    {% include 'django_spire/badge/success_badge.html' with badge_text='Published' %}
{% endif %}

{% if status == 'draft' %}
    {% include 'django_spire/badge/warning_badge.html' with badge_text='Draft' %}
{% endif %}

{% if status == 'archived' %}
    {% include 'django_spire/badge/secondary_badge.html' with badge_text='Archived' %}
{% endif %}
