<div class="card ms-0 shadow-sm rounded-3 bg-app-layer-two {% block card_class %}{% endblock %}">
    <div class="{% block card_padding %}p-3{% endblock %}">
        {% block card_content %}{% endblock %}
    </div>

    {% block card_footer %}{% endblock %}
</div>
