# Generated by Django 5.2.1 on 2025-06-03 19:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_spire_notification', '0002_pushnotification'),
    ]

    operations = [
        migrations.DeleteModel(
            name='PushNotification',
        ),
    ]
