<div class="row fs-7 text-app-side-navigation">
    <div class="col-auto pe-1">
        <span class="text-app-secondary">{{ divider_text }}</span>
    </div>
    <div class="col ps-0 pt-1">
        <hr class="m-0 mt-2">
    </div>
</div>
