{% extends 'django_spire/modal/modal.html' %}

{% block x-data_class %}
    d-inline
{% endblock %}

{% block modal_trigger_class %}
    d-inline
{% endblock %}

{% block modal_class %}
    align-items-center
{% endblock %}

{% block modal_content_class %}
    text-align-center
{% endblock %}
