<a
    @click="dispatch_modal_view('{{ view_url }}'); toggle_dropdown();"
    class="border-bottom fs--1 p-0 cursor-pointer text-decoration-none border-bottom bg-app-layer-three bg-app-layer-two-hover text-app-default-text-color"
>
    <div class="px-3 py-1 text-nowrap {{ link_css }}">
        {{ link_text }}
    </div>
</a>
